gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r27891 - gnunet/src/mesh


From: gnunet
Subject: [GNUnet-SVN] r27891 - gnunet/src/mesh
Date: Wed, 10 Jul 2013 17:11:21 +0200

Author: bartpolot
Date: 2013-07-10 17:11:20 +0200 (Wed, 10 Jul 2013)
New Revision: 27891

Modified:
   gnunet/src/mesh/mesh_common.c
Log:
- updated message numbers

Modified: gnunet/src/mesh/mesh_common.c
===================================================================
--- gnunet/src/mesh/mesh_common.c       2013-07-10 15:10:59 UTC (rev 27890)
+++ gnunet/src/mesh/mesh_common.c       2013-07-10 15:11:20 UTC (rev 27891)
@@ -91,34 +91,39 @@
     case 262: return "GNUNET_MESSAGE_TYPE_MESH_TO_ORIGIN";
 
       /**
        * Send origin an ACK that the path is complete
        */
-    case 263: return "GNUNET_MESSAGE_TYPE_MESH_DATA_ACK";
+    case 263: return "GNUNET_MESSAGE_TYPE_MESH_UNICAST_ACK";
 
       /**
+       * Send origin an ACK that TO_ORIGIN arrived
+       */
+    case 264: return "GNUNET_MESSAGE_TYPE_MESH_TO_ORIG_ACK";
+
+      /**
        * Avoid path timeouts
        */
-    case 264: return "GNUNET_MESSAGE_TYPE_MESH_PATH_KEEPALIVE";
+    case 265: return "GNUNET_MESSAGE_TYPE_MESH_PATH_KEEPALIVE";
 
       /**
        * Request the destuction of a path
        */
-    case 265: return "GNUNET_MESSAGE_TYPE_MESH_PATH_DESTROY";
+    case 266: return "GNUNET_MESSAGE_TYPE_MESH_PATH_DESTROY";
 
       /**
        * Request the destruction of a whole tunnel
        */
-    case 266: return "GNUNET_MESSAGE_TYPE_MESH_TUNNEL_DESTROY";
+    case 267: return "GNUNET_MESSAGE_TYPE_MESH_TUNNEL_DESTROY";
 
       /**
        * ACK for a data packet.
        */
-    case 267: return "GNUNET_MESSAGE_TYPE_MESH_ACK";
+    case 268: return "GNUNET_MESSAGE_TYPE_MESH_ACK";
 
       /**
        * POLL for ACK.
        */
-    case 268: return "GNUNET_MESSAGE_TYPE_MESH_POLL";
+    case 269: return "GNUNET_MESSAGE_TYPE_MESH_POLL";
 
       /**
        * Connect to the mesh service, specifying subscriptions
@@ -91,34 +91,39 @@
 
       /**
-       * Send origin an ACK that the path is complete
+       * Send origin an ACK that UNICAST arrived
        */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]